==> jersey-examples-2.4.1-all.zip: jersey/examples/simple-console/src/main/java/org/glassfish/jersey/examples/console/resources/Colours.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2010-2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.jersey.examples.console.resources;

import java.util.ArrayList;
import java.util.List;
import javax.ws.rs.GET;
import javax.ws.rs.Produces;
import javax.ws.rs.QueryParam;
import org.codehaus.jettison.json.JSONArray;

/**
 * A web resource for a list of colours.
 */
public class Colours {

    private static String colours[] = {"red","orange","yellow","green","blue","indigo","violet"};

    /**
     * Returns a list of colours as plain text, one colour per line.
     * @param filter If not empty, constrains the list of colours to only
     * those that contain this substring
     * @return the list of colours matching the filter
     */
    @GET
    @Produces("text/plain")
    public String getColourListAsText(@QueryParam("match") String filter) {
        StringBuilder buf = new StringBuilder();
        for (String colour: getMatchingColours(filter)) {
            buf.append(colour);
            buf.append('\n');
        }
        return buf.toString();
    }

    /**
     * Returns a list of colours as a JSON array.
     * @param filter If not empty, constrains the list of colours to only 
     * those that contain this substring
     * @return the list of colours matching the filter
     */
    @GET
    @Produces("application/json")
    public JSONArray getColourListAsJSON(@QueryParam("match") String filter) {
        return new JSONArray(getMatchingColours(filter));
    }

    /**
     * Returns a list of colours.
     * @param filter If not empty, constrains the list of colours to only
     * those that contain this substring
     * @return the list of colours matching the filter
     */
    public static List<String> getMatchingColours(String filter) {
        List<String> matches = new ArrayList<String>();

        for (String colour: colours) {
            if (filter==null || filter.length()==0 || colour.contains(filter)) {
                matches.add(colour);
            }
        }

        return matches;
    }
}

==> jersey-examples-2.45-all.zip: jersey/examples/simple-console/src/main/java/org/glassfish/jersey/examples/console/resources/Colours.java <==
/*
 * Copyright (c) 2010, 2018 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Distribution License v. 1.0, which is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

package org.glassfish.jersey.examples.console.resources;

import java.util.ArrayList;
import java.util.List;

import javax.ws.rs.GET;
import javax.ws.rs.Produces;
import javax.ws.rs.QueryParam;

import org.codehaus.jettison.json.JSONArray;

/**
 * A web resource for a list of colours.
 */
public class Colours {

    private static String colours[] = {"red", "orange", "yellow", "green", "blue", "indigo", "violet"};

    /**
     * Returns a list of colours as plain text, one colour per line.
     * @param filter If not empty, constrains the list of colours to only
     * those that contain this substring
     * @return the list of colours matching the filter
     */
    @GET
    @Produces("text/plain")
    public String getColourListAsText(@QueryParam("match") String filter) {
        StringBuilder buf = new StringBuilder();
        for (String colour : getMatchingColours(filter)) {
            buf.append(colour);
            buf.append('\n');
        }
        return buf.toString();
    }

    /**
     * Returns a list of colours as a JSON array.
     * @param filter If not empty, constrains the list of colours to only
     * those that contain this substring
     * @return the list of colours matching the filter
     */
    @GET
    @Produces("application/json")
    public JSONArray getColourListAsJSON(@QueryParam("match") String filter) {
        return new JSONArray(getMatchingColours(filter));
    }

    /**
     * Returns a list of colours.
     * @param filter If not empty, constrains the list of colours to only
     * those that contain this substring
     * @return the list of colours matching the filter
     */
    public static List<String> getMatchingColours(String filter) {
        List<String> matches = new ArrayList<>();

        for (String colour : colours) {
            if (filter == null || filter.length() == 0 || colour.contains(filter)) {
                matches.add(colour);
            }
        }

        return matches;
    }
}
